

//      ********************************************************************
//      *                                                                  *
//      *                Bipolar NEMA17 absolute moves                   *
//      *                   lingib     1 January 2022                      *
//      *    https://www.instructables.com/member/lingib/instructables/    *
//      *                                                                  *
//      *          Adapted from the unipolar 28BYJ-28 example              *
//      *                 "Example2_AbsoluteMoves"                     *
//      *     https://github.com/Stan-Reifel/TinyStepper_28BYJ_48          *
//      *               S . Reifel & Co.     6/24/2018                     *
//      *                                                                  *
//      ********************************************************************
//
// The "TinyStepper" library used in this example is a bipolar version of 
// the unipolar "TinyStepper_28BYJ_48" library found at:
//    https://github.com/Stan-Reifel/TinyStepper_28BYJ_48
//
// The Documentation for both libraries is the same and can be found at:
//    https://github.com/Stan-Reifel/TinyStepper_28BYJ_48
//
// This example requires that a bipolar NEMA17 stepper motor (or similar) 
// be connected to your Arduino via an L298N H-bridge driver board.  
//
// This example is similar to Example1_BasicStepper.ino except that is uses 
// "absolute" moves instead of "relative" ones.  Relative moves will use a  
// coordinate system that is relative to the motor's current position.  
// Absolute moves use a coordinate system that is referenced to the original  
// position ofthe motor when it is turned on.
//
// For example moving relative 2000 steps, then another 2000, then another  
// 2000 will turn 6000 steps in total (and end up at an absolute position of 
// 6000).
//
// However issuing an absolute move to position 2048 will rotate forward one   
// rotation.  Then running the next absolute move to position 4096 will turn  
// just one more revolution in the same direction.  Finally moving to position 0  
// will rotate backward two revolutions, back to the starting position.
//
// ***********************************************************************


#include <TinyStepper.h>


//
// pin assignments, any digital pins can be used
//
const int LED_PIN = 13;
const int MOTOR_IN1_PIN = 11;
const int MOTOR_IN2_PIN = 10;
const int MOTOR_IN3_PIN = 9;
const int MOTOR_IN4_PIN = 8;


const int STEPS_PER_REVOLUTION = 200;


//
// create the stepper motor object
//
TinyStepper stepper;



void setup() 
{
  //
  // setup the LED pin and enable print statements
  //
  pinMode(LED_PIN, OUTPUT);   
  Serial.begin(115200);


  //
  // connect and configure the stepper motor to its IO pins
  //
  stepper.connectToPins(MOTOR_IN1_PIN, MOTOR_IN2_PIN, MOTOR_IN3_PIN, MOTOR_IN4_PIN);
}



void loop() 
{
  //
  // Note: This example uses "absolute" motions, meaning the values
  // sent to the move commands use a coordinate system where 0 is the
  // initial position of the motor when it is first turned on.
  //

  //
  // set the speed and acceleration rates for the stepper motor
  //
  stepper.setSpeedInStepsPerSecond(50);                         // Slow speed
  stepper.setAccelerationInStepsPerSecondPerSecond(250);        // Acceleration

  //
  // Rotate the motor to position 200 (turning one revolution). This 
  // function call will not return until the motion is complete.
  //
  stepper.moveToPositionInSteps(200);                           // Move 1 rotation

  //
  // now that the rotation has finished, delay 1 second before starting 
  // the next move
  //
  delay(1000);

  //
  // rotate to position 400 (turning just one revolution more since it is 
  // already at position 200)
  //
  stepper.moveToPositionInSteps(400);                          // Addd 1 further rotation
  delay(1000);

  //
  // Now speedup the motor and return to it's home position of 0, resulting 
  // in rotating backward two turns.  Note if you tell a stepper motor to go 
  // faster than it can, it just stops.
  //
  stepper.setSpeedInStepsPerSecond(500);                      // Speed now 10x faster
  stepper.moveToPositionInSteps(0);                           // Rotate twice coming back
  delay(2000);
}
